Skip to main content

FFpy is a command-line tool that measures the execution time of Python scripts. It provides flexibility by allowing you to specify the time unit (milliseconds or seconds) and the number of runs for more accurate measurements.

Background 🚀

As an undergraduate software engineer with Python as my weapon of choice for coding, I often found myself curious about the execution time of my scripts. While solutions like timeit module exist, I wanted a seamless way to measure execution time without adding another line of code to my programs. This led to the creation of FFpy.

In my coding journey, especially while tackling Data Structures and Algorithms problems and optimizing code, understanding the execution time can provide valuable insights.

FFpy aims to be a simple yet powerful tool for easily benchmarking performance without the need to modify your existing codebase. I believe in keeping things straightforward. FFpy is designed to be a minimalistic, no-nonsense module that integrates seamlessly into your workflow, allowing you to focus on coding while effortlessly obtaining execution time metrics.

Installation 🛠️

Install FFpy using pip:

pip install ffpy

Alternatively, you can clone this repository:

git clone https://github.com/anxkhn/FFpy.git
cd FFpy
pip install .

Usage 🚨

After installation, you can use FFpy to measure the execution time of your Python scripts. Here’s the basic syntax:

ffpy <filename.py/folder> <filename2.py> [-u <unit>] [-n <num_runs>] [-s] [-m <mode>] [-v] [-h]
  • <filename.py/folder>: Replace with the actual filename or folder of your Python script(s) in the current directory.

  • <filename2.py>: Optional second script for comparison.

  • -u, --unit: Optional flag to specify the time unit (ms or s, default is ms).

  • -n, --number: Optional flag to specify the number of runs (default is 1).

  • -s, --silent: Optional flag to run the script silently (suppress output).

  • -m, --mode: Optional flag to specify the threads (single or multi, default is single).

  • -v, --version: Display script version.

  • -h, --help: Display help message.

Examples 🌈

  1. Measure the execution time of a script in milliseconds:

ffpy script.py
  1. Measure the execution time in seconds:

ffpy script.py -u s
  1. Run the script 10 times and measure the average execution time:

ffpy script.py -n 10
  1. Run the script silently:

ffpy script.py -s
  1. Run scripts concurrently using multithreading mode:

ffpy script.py -m multi

Note on Multithreading Mode:

When using the multithreading mode (-m multi), the script will be executed concurrently in a multithreaded fashion, leveraging multiple cores on your system. It’s important to note that the average execution time in multithreading mode may not be equal to running the program once, as multithreading introduces parallelism and can lead to variations in execution times. Learn more [1] about multithreading.

Types of Operation:

  • Single File: Measure the execution time of a single script.

ffpy script1.py -s

Output:

Execution time: 30.1924 ms
  • Double File (Comparison): Compare the execution times of two scripts and determine the percentage difference.

  1. Compare the execution times of two scripts:

ffpy script1.py script2.py -s

Output:

script1.py
Execution time: 29.2735 ms
script2.py
Execution time: 533.9346 ms
script1.py is 1723.95% faster than script2.py
  • More Than Two Files (Detailed Table): Compare execution times of multiple scripts and display a detailed table with filenames and average execution times.

  1. Compare execution times of multiple scripts and display a detailed table:

ffpy script1.py script2.py script3.py -s

or

ffpy path/to/scripts

Output:

script1.py
Execution time: 30.0028 ms
script2.py
Execution time: 533.4799 ms
script3.py
Execution time: 1035.9304 ms
╒════════════╤═══════════════════════════════╕
│ Filename   │   Average Execution Time (ms) │
╞════════════╪═══════════════════════════════╡
│ script1.py │                       30.0028 │
├────────────┼───────────────────────────────┤
│ script2.py │                      533.48   │
├────────────┼───────────────────────────────┤
│ script3.py │                     1035.93   │
╘════════════╧═══════════════════════════════╛

How to Use 🤔

  1. Start by including a simple hello.py Python script as an example:

print("Hello, FFpy!")

You can measure its execution time using FFpy:

ffpy hello.py

This should yield the following output:

Hello, FFpy!
Execution time: XX.XX ms
  1. Now, let’s examine the runtime of two different sorting algorithms. We have a list of 1000 integers, and we’ll use merge_sort.py and bubble_sort.py to sort them as examples:

ffpy merge_sort.py bubble_sort.py --silent

This will produce the following output:

merge_sort.py
Execution time: 33.2839 ms
bubble_sort.py
Execution time: 65.3996 ms
merge_sort.py is 96.49% faster than bubble_sort.py.

This difference in execution time is due to the fact that Merge sort is faster than bubble sort, thanks to its efficient divide-and-conquer approach, resulting in a time complexity of O(n log n). On the other hand, bubble sort, with its quadratic time complexity of O(n^2), proves to be less efficient for large datasets. We can clearly see the execution time differences between two programs. Learn more [2] about time complexity.

Contributing 🤝

If you’d like to contribute to FFpy, feel free to fork the repository and submit a pull request.

License 📜

This project is licensed under the GPLv3 License - check out this website for more information.

Metadata

Release files for FFpy 1.6.2

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for FFpy 1.6.2
File Size Uploaded
FFpy-1.6.2.tar.gz 6.3 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for FFpy 1.6.2
File Interpreter ABI Platform
FFpy-1.6.2-py3-none-any.whl Python 3 none any Details

Total release size: 13.9 kB

Release files / FFpy-1.6.2.tar.gz

Download URL FFpy-1.6.2.tar.gz
Size 6.3 kB
Tags Source
SHA-256 checksum
How to use checksums
a88e150b4d697618d3ddc2e414ff45b4c9ea3f26396bae59019f5650346f7e4c
BLAKE2b-256 checksum
How to use checksums
5d5e5a379d072ea77ff0ceedee93224ac532e8919fb820c2d8475061f47f9fab
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/4.0.2 CPython/3.11.6

Release files / FFpy-1.6.2-py3-none-any.whl

Download URL FFpy-1.6.2-py3-none-any.whl
Size 7.6 kB
Tags Python 3
SHA-256 checksum
How to use checksums
e48c2ca4a9aa09d1d5551d437bbfde97e10e51b7f99ae97e11cf9fd47334f949
BLAKE2b-256 checksum
How to use checksums
9d1fcd20418ed40afca0dac139f11eb0dcf385b834234aa1e04abf21efadcd9f
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/4.0.2 CPython/3.11.6

Release history Release notifications | RSS feed

This release

1.6.2 This release

2 release files

1.6.1

2 release files

1.6.0

2 release files

1.5.0

2 release files

1.4.1

2 release files

1.4.0

2 release files

1.3.0

2 release files

1.2.0

2 release files

1.1.0

1 release file

1.0

1 release file

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page